@@ -133,7 +133,8 @@ class Server(object):
                 first = docs[0]
                 operation.client._process_response(
                     first, operation.session)
-                _check_command_response(first)
+                _check_command_response(
+                    first, sock_info.max_wire_version)
         except Exception as exc:
             if publish:
                 duration = datetime.now() - start
@@ -225,8 +226,5 @@ class Server(object):
             request_id, data = message
             return request_id, data, 0
 
-    def __str__(self):
-        d = self._description
-        return '<Server "%s:%s" %s>' % (
-            d.address[0], d.address[1],
-            SERVER_TYPE._fields[d.server_type])
+    def __repr__(self):
+        return '<%s %r>' % (self.__class__.__name__, self._description)
